==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: th\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "ตารางเวลา"

]
, "Account"
: "บัญชี"

, "Time Account (Number - Title)"
: "บัญชีเวลา (หมายเลข - ตำแหน่ง)"

, "Billable"
: "ที่เรียกเก็บเงินได้"

, "Cleared in"
: ""

, "Invoice"
: ""

, "Cleared"
: "เคลียร์แล้ว"

, "Date"
: "วันที่"

, "Start time"
: "เวลาที่เริ่ม"

, "End time"
: ""

, "Duration"
: "ระยะเวลา"

, "Description"
: "คำอธิบาย"

, "Type"
: ""

, "Time Account closed"
: "บัญชีเวลาปิดแล้ว"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""

]
, "Contract"
: "สัญญา"

, "Title"
: "คำนำหน้าชื่อ"

, "Number"
: "ลำดับ"

, "Price"
: ""

, "Status"
: "สถานะ"

, "Billed"
: "เรียกเก็บเงินแล้ว"

, "Cleared at"
: "เคลียร์แล้วเมื่อ"

, "Booking deadline"
: "สิ้นสุดการจอง"

, "Responsible"
: ""

, "Cost Center"
: "ศูนย์ต้นทุน"

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "บัญชีเวลา"

]
, "Time Account - Status"
: "บัญชีเวลา - สถานะ"

, "closed"
: "ปิดแล้ว"

, "open"
: "เปิด"

, "Not a valid time"
: "เวลาใช้ไม่ได้"

, "Time Account - Billed"
: "บัญชีเวลา - เรียกเก็บเงินแล้ว"

, "not yet billed"
: "ยังไม่ได้เรียกเก็บเงิบ"

, "to bill"
: "ที่จะต้องเรียกเก็บเงิน"

, "billed"
: "เรียกเก็บเงินแล้ว"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""

]
, "Favorite"
: ""

, "Cleared In"
: "เคลียร์แล้วใน"

, "Select Time Account..."
: "เลือกบัญชีเวลา..."

, "Start"
: "เริ่มต้น"

, "not set"
: "ยังไม่ได้กำหนด"

, "End"
: ""

, "Enter description..."
: "ใส่ คำอธิบาย"

, "Need for Clarification"
: ""

, "Failed"
: "ได้ล้มเหลว"

, "Could not save {0}."
: "ไม่สามารถจัดเก็บ {0} ได้"

, "Booking deadline for this Timeaccount has been exceeded."
: "สิ้นสุดการจองสำหรับบัญชีเวลานี้ได้ถูกขยายออกไป"

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""

]
, "Book Own"
: "จองเอง"

, "The grant to add Timesheets to this Timeaccount"
: "อนุญาตให้เพิ่มตารางเวลาเข้าไปบัญชีเวลานี้ได้"

, "View All"
: "ดูทั้งหมด"

, "The grant to view Timesheets of other users"
: "อนุญาตให้ดูตารางเวลาของผู้ใช้งานคนอื่นๆได้"

, "Book All"
: "จองทั้งหมด"

, "The grant to add Timesheets for other users"
: "อนุญาตให้เพิ่มตารางเวลาสำหรับผู้ใช้งานคนอื่นๆได้"

, "Manage Clearing"
: "จัดการการล้าง"

, "The grant to manage clearing of Timesheets"
: "อนุญาตให้จัดการการล้างตารางเวลาได้"

, "without contract"
: "ปราศจากสัญญา"

, "without responsible"
: ""

, "timeframe"
: "กรอบเวลา"

, "summary"
: "ข้อสรุป"

, "Total Timesheets"
: "ตารางเวลารวบยอด"

, "Billable Timesheets"
: "ตารางเวลาที่เรียกเก็บเงินได้"

, "Total Time"
: "เวลารวบยอด"

, "Time of Billable Timesheets"
: "ช่วงเวลาของตารางเวลาที่เรียกเก็บเงินได้"

, "Detail"
: "รายละเอียด"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "ส่งออกตารางเวลา"

, "Export as ODS"
: "ส่งออก เป็นไฟล์ ODS"

, "Export as CSV"
: "ส่งออก เป็นไฟล์ CSV"

, "Export as ..."
: "ส่งออก เป็น ..."

, "Add New Timeaccount"
: ""

, "Unit"
: "หน่วย/ แผนก"

, "Unit Price"
: "ราคาต่อหน่วย"

, "Budget"
: "วงเงิน"

, "Timesheets are billable"
: "เป็นตารางเวลาที่เรียกเก็บเงินได้"

, "Access"
: "การเข้าใช้"

, "Permissions"
: "สิทธิ์ที่อนุญาต"

, "Show closed"
: "แสดงที่ปิดแล้ว"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "การกำหนดค่าส่งออกตารางเวลา ODS"

, "Use this configuration for the timesheet ODS export."
: "ใช้กำหนดค่านี้สำหรับการส่งออกตารางเวลา ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "ค่าหลัก"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "ไม่มีเลย"

, "last week"
: "สัปดาห์ที่แล้ว"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "จัดการบัญชีเวลา"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "เพิ่ม แก้ไข และลบบัญชีเวลา (รวมถึงการอนุญาตเรื่องตารางเวลาทั้งหมด)"

, "Add timeaccounts"
: "เพิ่มบัญชีเวลา"

, "Manage shared timeaccount favorites"
: "จัดการ บัญชีเวลาร่วมที่ใช้บ่อย"

, "Create or update shared timeaccount favorites"
: "สร้าง หรือ ปรับปรุง บัญชีเวลาร่วมที่ใช้บ่อย"

, "Manage shared timesheet favorites"
: "จัดการ ตารางเวลาร่วมที่ใช้บ่อย"

, "Create or update shared timesheet favorites"
: "สร้าง หรือ ปรับปรุงตารางเวลาร่วมที่ใช้บ่อย"

, "My Timesheets today"
: "ตารางเวลาของฉัน วันนี้"

, "My Timesheets this week"
: "ตารางเวลาของฉัน สัปดาห์นี้"

, "My Timesheets last week"
: "ตารางเวลาของฉัน สัปดาห์ที่แล้ว"

, "My Timesheets this month"
: "ตารางเวลาของฉัน เดือนนี้"

, "My Timesheets last month"
: "ตารางเวลาของฉัน เดือนที่แล้ว"

, "Timeaccounts to bill"
: "บัญชีเวลาที่จะต้องเรียกเก็บเงิน"

, "Timeaccounts not yet billed"
: "บัญชีเวลาที่ยังไม่ได้เรียกเก็บเงิน"

, "Timeaccounts already billed"
: "บัญชีเวลาที่ได้เรียกเก็บเงินแล้ว"

, "Timetracker"
: "ตัวติดตามเวลา"

, "Timesheet"
: "ตารางเวลา"

, "Timeaccount"
: ""

, "Time Account"
: "บัญชีเวลา"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "กรอบเวลา"

, "summary"
: "ข้อสรุป"

, "Total Timesheets"
: "ตารางเวลารวบยอด"

, "Billable Timesheets"
: "ตารางเวลาที่เรียกเก็บเงินได้"

, "Total Time"
: "เวลารวบยอด"

, "Time of Billable Timesheets"
: "ช่วงเวลาของตารางเวลาที่เรียกเก็บเงินได้"

, "Description"
: "คำอธิบาย"

, "Detail"
: "รายละเอียด"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "ส่งออกตารางเวลา"

, "Export as ODS"
: "ส่งออก เป็นไฟล์ ODS"

, "Export as CSV"
: "ส่งออก เป็นไฟล์ CSV"

, "Export as ..."
: "ส่งออก เป็น ..."

, "Timesheet, Timesheets"
: [
  "ตารางเวลา"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""

]
, "Failed"
: "ได้ล้มเหลว"

, "Could not save {0}."
: "ไม่สามารถจัดเก็บ {0} ได้"

, "Booking deadline for this Timeaccount has been exceeded."
: "สิ้นสุดการจองสำหรับบัญชีเวลานี้ได้ถูกขยายออกไป"

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "สัญญา"

, "without contract"
: "ปราศจากสัญญา"

, "Add New Timeaccount"
: ""

, "Unit"
: "หน่วย/ แผนก"

, "Unit Price"
: "ราคาต่อหน่วย"

, "Factor"
: ""

, "Budget"
: "วงเงิน"

, "Status"
: "สถานะ"

, "closed"
: "ปิดแล้ว"

, "open"
: "เปิด"

, "Cleared In"
: "เคลียร์แล้วใน"

, "Cleared at"
: "เคลียร์แล้วเมื่อ"

, "Cost Center"
: "ศูนย์ต้นทุน"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "เป็นตารางเวลาที่เรียกเก็บเงินได้"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "บัญชีเวลา"

]
, "Number"
: "ลำดับ"

, "Title"
: "คำนำหน้าชื่อ"

, "Access"
: "การเข้าใช้"

, "Permissions"
: "สิทธิ์ที่อนุญาต"

, "Time Account - Billed"
: "บัญชีเวลา - เรียกเก็บเงินแล้ว"

, "not yet billed"
: "ยังไม่ได้เรียกเก็บเงิบ"

, "to bill"
: "ที่จะต้องเรียกเก็บเงิน"

, "billed"
: "เรียกเก็บเงินแล้ว"

, "Time Account - Status"
: "บัญชีเวลา - สถานะ"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""

]
, "Book Own"
: "จองเอง"

, "The grant to add Timesheets to this Timeaccount"
: "อนุญาตให้เพิ่มตารางเวลาเข้าไปบัญชีเวลานี้ได้"

, "View All"
: "ดูทั้งหมด"

, "The grant to view Timesheets of other users"
: "อนุญาตให้ดูตารางเวลาของผู้ใช้งานคนอื่นๆได้"

, "Book All"
: "จองทั้งหมด"

, "The grant to add Timesheets for other users"
: "อนุญาตให้เพิ่มตารางเวลาสำหรับผู้ใช้งานคนอื่นๆได้"

, "Manage Clearing"
: "จัดการการล้าง"

, "The grant to manage clearing of Timesheets"
: "อนุญาตให้จัดการการล้างตารางเวลาได้"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""

]
, "Favorite"
: ""

, "Show closed"
: "แสดงที่ปิดแล้ว"

, "Timesheets ODS export configuration"
: "การกำหนดค่าส่งออกตารางเวลา ODS"

, "Use this configuration for the timesheet ODS export."
: "ใช้กำหนดค่านี้สำหรับการส่งออกตารางเวลา ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "ค่าหลัก"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "ไม่มีเลย"

, "last week"
: "สัปดาห์ที่แล้ว"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: ""

, "Billed"
: "เรียกเก็บเงินแล้ว"

, "Booking deadline"
: "สิ้นสุดการจอง"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "บัญชี"

, "Time Account (Number - Title)"
: "บัญชีเวลา (หมายเลข - ตำแหน่ง)"

, "Billable"
: "ที่เรียกเก็บเงินได้"

, "Cleared"
: "เคลียร์แล้ว"

, "Date"
: "วันที่"

, "Start time"
: "เวลาที่เริ่ม"

, "End time"
: ""

, "Duration"
: "ระยะเวลา"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "บัญชีเวลาปิดแล้ว"

, "Timetracker"
: "ตัวติดตามเวลา"

, "Timeaccounts to bill"
: "บัญชีเวลาที่จะต้องเรียกเก็บเงิน"

, "Timeaccounts not yet billed"
: "บัญชีเวลาที่ยังไม่ได้เรียกเก็บเงิน"

, "Timeaccounts already billed"
: "บัญชีเวลาที่ได้เรียกเก็บเงินแล้ว"

, "My Timesheets today"
: "ตารางเวลาของฉัน วันนี้"

, "My Timesheets this week"
: "ตารางเวลาของฉัน สัปดาห์นี้"

, "My Timesheets last week"
: "ตารางเวลาของฉัน สัปดาห์ที่แล้ว"

, "My Timesheets this month"
: "ตารางเวลาของฉัน เดือนนี้"

, "My Timesheets last month"
: "ตารางเวลาของฉัน เดือนที่แล้ว"

, "Manage timeaccounts"
: "จัดการบัญชีเวลา"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "เพิ่ม แก้ไข และลบบัญชีเวลา (รวมถึงการอนุญาตเรื่องตารางเวลาทั้งหมด)"

, "Add timeaccounts"
: "เพิ่มบัญชีเวลา"

, "Manage shared timeaccount favorites"
: "จัดการ บัญชีเวลาร่วมที่ใช้บ่อย"

, "Create or update shared timeaccount favorites"
: "สร้าง หรือ ปรับปรุง บัญชีเวลาร่วมที่ใช้บ่อย"

, "Manage shared timesheet favorites"
: "จัดการ ตารางเวลาร่วมที่ใช้บ่อย"

, "Create or update shared timesheet favorites"
: "สร้าง หรือ ปรับปรุงตารางเวลาร่วมที่ใช้บ่อย"






, "Timesheet"
: "ตารางเวลา"

, "Timeaccount"
: ""

, "Time Account"
: "บัญชีเวลา"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
